@@ -267,6 +267,17 @@ static const SeqStr *color_16_list [] =
     NULL
 };
 
+static const SeqStr *color_8_list [] =
+{
+    color_8_seqs,
+    NULL
+};
+
+static const SeqStr *color_mono_list [] =
+{
+    NULL
+};
+
 static const SeqStr color_fbterm_seqs [] =
 {
     { CHAFA_TERM_SEQ_SET_COLOR_FG_16, "\033[1;%1}" },
@@ -392,6 +403,7 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
     const gchar *mlterm;
     const gchar *nvim;
     const gchar *nvim_tui_enable_true_color;
+    const gchar *eat_shell_integration_dir;
     gchar *comspec = NULL;
     const SeqStr **color_seq_list = color_256_list;
     const SeqStr *gfx_seqs = NULL;
@@ -411,6 +423,7 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
     mlterm = getenv_or_blank (envp, "MLTERM");
     nvim = getenv_or_blank (envp, "NVIM");
     nvim_tui_enable_true_color = getenv_or_blank (envp, "NVIM_TUI_ENABLE_TRUE_COLOR");
+    eat_shell_integration_dir = getenv_or_blank (envp, "EAT_SHELL_INTEGRATION_DIR");
 
     /* The MS Windows 10 TH2 (v1511+) console supports ANSI escape codes,
      * including AIX and DirectColor sequences. We detect this early and allow
@@ -544,6 +557,21 @@ detect_capabilities (ChafaTermInfo *ti, gchar **envp)
     if (!strcmp (term, "rxvt-unicode"))
         color_seq_list = color_16_list;
 
+    /* Eat uses the "eat-" prefix for TERM.
+     * Eat also sets EAT_SHELL_INTEGRATION_DIR in the environment. */
+    if (!strncmp (term, "eat-", 4) || strcmp (eat_shell_integration_dir, ""))
+        gfx_seqs = sixel_seqs;
+    if (!strcmp (term, "eat-truecolor"))
+        color_seq_list = color_direct_list;
+    if (!strcmp (term, "eat-256color"))
+        color_seq_list = color_256_list;
+    if (!strcmp (term, "eat-16color"))
+        color_seq_list = color_16_list;
+    if (!strcmp (term, "eat-color"))
+        color_seq_list = color_8_list;
+    if (!strcmp (term, "eat-mono"))
+        color_seq_list = color_mono_list;
+
     /* 'screen' does not like truecolor at all, but 256 colors works fine.
      * Sometimes we'll see the outer terminal appended to the TERM string,
      * like so: screen.xterm-256color */
